@@ -37,9 +37,10 @@ namespace KTextEditor
 
 namespace Kate
 {
-
   class PluginConfigPageInterface;
   class Plugin;
+  class PluginView;
+
   /**
    * \brief Interface to a mainwindow.
    *
@@ -108,6 +109,12 @@ namespace Kate
        * \return the central widget
        */
       class QWidget *centralWidget() const;
+      
+      /**
+       * Get a list of all views.
+       * @return all views
+       */
+      const QList<KTextEditor::View *> &views () const;
 
       /*
        * View stuff, here all stuff belong which allows to
@@ -134,7 +141,7 @@ namespace Kate
        * \param encoding the preferred encoding. If encoding is QString() the
        *        encoding will be guessed or the default encoding will be used.
        * \return a pointer to the created view for the new document, if a document
-       *         with this url is already existing, it's view will be activated
+       *         with this url is already existing, its view will be activated
        */
       KTextEditor::View *openUrl (const KUrl &url, const QString &encoding = QString());
 
@@ -145,7 +152,7 @@ namespace Kate
 #undef signals
 #define signals public
 #endif
-    Q_SIGNALS:
+    signals:
 #ifndef Q_MOC_RUN
 #undef signals
 #define signals protected
@@ -160,7 +167,6 @@ namespace Kate
        * This signal is emitted whenever a new view is created
        * @since 4.2
        */
-
       void viewCreated(KTextEditor::View * view);
 
       /**
@@ -168,6 +174,25 @@ namespace Kate
        */
       void unhandledShortcutOverride (QEvent *e);
 
+      /**
+       * This signal is emitted when a Plugin::View is created for this main window.
+       *
+       * @param name name of plugin
+       * @param pluginView the new plugin view
+       */
+      void pluginViewCreated (const QString &name, Kate::PluginView *pluginView);
+
+      /**
+       * This signal is emitted when the Plugin::View got deleted.
+       *
+       * @param name name of plugin
+       * @param pluginView the deleted plugin view
+       *
+       * Warning !!! DO NOT ACCESS THE DATA REFERENCED BY THE POINTER, IT IS ALREADY INVALID
+       * Use the pointer only to remove mappings in hash or maps
+       */
+      void pluginViewDeleted (const QString &name, Kate::PluginView *pluginView);
+
       /*
        * ToolView stuff, here all stuff belong which allows to
        * add/remove and manipulate the toolview of this main windows
@@ -212,7 +237,6 @@ namespace Kate
        */
       QWidget *createToolView (Kate::Plugin* plugin, const QString &identifier, MainWindow::Position pos, const QPixmap &icon, const QString &text);
 
-      
       /**
        * Move the toolview \p widget to position \p pos.
        * \param widget the toolview to move, where the widget was constructed
@@ -239,19 +263,25 @@ namespace Kate
        */
       bool hideToolView (QWidget *widget);
 
-      
       /**
        * This function is used by a plugin to open the kate configuration dialog
-       * at one of it's own config pages.
+       * at one of its own config pages.
        * \param configpageinterface the plugin config page interface of the plugin which requests the settings dialog
        * \param id the positional id of the page within the configuration
        */
       void showPluginConfigPage(Kate::PluginConfigPageInterface *configpageinterface,uint id);
-      
+
+      /**
+       * Get a plugin view with identifier \p name.
+       * \param name the plugin's name
+       * \return pointer to the plugin view if a plugin with \p name is loaded and has a view for this mainwindow,
+       *         otherwise NULL
+       */
+      PluginView *pluginView (const QString &name);
+
     private:
       class PrivateMainWindow *d;
   };
-
 }
 
 #endif
