@@ -153,6 +153,7 @@ KatePluginSearchView::KatePluginSearchView(Kate::MainWindow *mainWin, Kate::Appl
 Kate::XMLGUIClient(KatePluginSearchFactory::componentData()),
 m_kateApp(application),
 m_curResults(0),
+m_searchJustOpened(false),
 m_projectPluginView(0)
 {
     KAction *a = actionCollection()->addAction("search_in_files");
@@ -335,9 +336,14 @@ void KatePluginSearchView::openSearchView()
                 selection = selection.left(selection.size() -1);
             }
             if (!selection.isEmpty() && !selection.contains('\n')) {
+                m_ui.searchCombo->blockSignals(true);
                 m_ui.searchCombo->lineEdit()->setText(selection);
+                m_ui.searchCombo->blockSignals(false);
             }
         }
+        m_ui.searchCombo->lineEdit()->selectAll();
+        m_searchJustOpened = true;
+        searchPatternChanged();
     }
 }
 
@@ -591,8 +597,8 @@ void KatePluginSearchView::clearMarks()
             QHashIterator<int, KTextEditor::Mark*> i(marks);
             while (i.hasNext()) {
                 i.next();
-                if (i.value()->type == KTextEditor::MarkInterface::markType32) {
-                    iface->removeMark(i.value()->line, i.value()->type);
+                if (i.value()->type & KTextEditor::MarkInterface::markType32) {
+                    iface->removeMark(i.value()->line, KTextEditor::MarkInterface::markType32);
                 }
             }
         }
@@ -612,8 +618,8 @@ void KatePluginSearchView::clearDocMarks(KTextEditor::Document* doc)
         QHashIterator<int, KTextEditor::Mark*> i(marks);
         while (i.hasNext()) {
             i.next();
-            if (i.value()->type == KTextEditor::MarkInterface::markType32) {
-                iface->removeMark(i.value()->line, i.value()->type);
+            if (i.value()->type & KTextEditor::MarkInterface::markType32) {
+                iface->removeMark(i.value()->line, KTextEditor::MarkInterface::markType32);
             }
         }
     }
@@ -661,6 +667,7 @@ void KatePluginSearchView::searchDone()
     indicateMatch(m_curResults->tree->topLevelItemCount() > 0);
     m_curResults = 0;
     m_toolView->unsetCursor();
+    m_searchJustOpened = false;
 }
 
 void KatePluginSearchView::searchWhileTypingDone()
@@ -669,21 +676,18 @@ void KatePluginSearchView::searchWhileTypingDone()
         return;
     }
 
-    if (m_curResults->tree->topLevelItemCount() > 0) {
-        m_curResults->tree->setCurrentItem(m_curResults->tree->topLevelItem(0));
-        m_curResults->setFocus(Qt::OtherFocusReason);
-    }
     m_curResults->tree->resizeColumnToContents(0);
     m_curResults->buttonContainer->setEnabled(true);
 
     connect(m_curResults->tree, SIGNAL(itemChanged(QTreeWidgetItem*,int)), m_curResults, SLOT(checkCheckedState()));
 
-    indicateMatch(m_curResults->tree->topLevelItemCount() > 0);
-    if (m_curResults->tree->topLevelItemCount() > 0) {
+    if (!m_searchJustOpened && (m_curResults->tree->topLevelItemCount() > 0)) {
         itemSelected(m_curResults->tree->topLevelItem(0));
     }
+    indicateMatch(m_curResults->tree->topLevelItemCount() > 0);
     m_curResults = 0;
     m_ui.searchCombo->lineEdit()->setFocus();
+    m_searchJustOpened = false;
 }
 
 void KatePluginSearchView::indicateMatch(bool hasMatch) {
@@ -879,6 +883,13 @@ void KatePluginSearchView::writeSessionConfig(KConfigBase* config, const QString
 
 void KatePluginSearchView::addTab()
 {
+    if ((sender() != m_ui.newTabButton) &&
+        (m_ui.resultTabWidget->count() >  0) &&
+        m_ui.resultTabWidget->tabText(m_ui.resultTabWidget->currentIndex()).isEmpty())
+    {
+        return;
+    }
+
     Results *res = new Results();
 
     connect(res->tree, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
