@@ -62,6 +62,7 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     bool commandEnterInsertModeAppend();
     bool commandEnterInsertModeAppendEOL();
     bool commandEnterInsertModeBeforeFirstNonBlankInLine();
+    bool commandEnterInsertModeLast();
 
     bool commandEnterVisualMode();
     bool commandEnterVisualLineMode();
@@ -96,8 +97,11 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     bool commandYankLine();
     bool commandYankToEOL();
 
-    bool commandPaste();
-    bool commandPasteBefore();
+    bool commandPasteLeaveCursorAtStart();
+    bool commandPasteBeforeLeaveCursorAtStart();
+
+    bool commandPasteLeaveCursorAtEnd();
+    bool commandPasteBeforeLeaveCursorAtEnd();
 
     bool commandDeleteChar();
     bool commandDeleteCharBackward();
@@ -105,7 +109,8 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     bool commandReplaceCharacter();
 
     bool commandSwitchToCmdLine();
-    bool commandSearch();
+    bool commandSearchBackward();
+    bool commandSearchForward();
     bool commandUndo();
     bool commandRedo();
 
@@ -156,6 +161,12 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     bool commandFormatLine();
     bool commandFormatLines();
 
+    bool commandCollapseToplevelNodes();
+    bool commandCollapseLocal();
+    bool commandExpandAll();
+    bool commandExpandLocal();
+    bool commandToggleRegionVisibility();
+
     // MOTIONS
 
     KateViRange motionLeft();
@@ -218,6 +229,9 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     KateViRange motionToNextVisualLine();
     KateViRange motionToPrevVisualLine();
 
+    KateViRange motionToBeforeParagraph();
+    KateViRange motionToAfterParagraph();
+
     // TEXT OBJECTS
 
     KateViRange textObjectAWord();
@@ -256,6 +270,7 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     const QStringList getMappings() const;
     virtual void reset();
 
+    void setMappingTimeout(int timeoutMS);
   protected:
     void resetParser();
     void initializeCommands();
@@ -263,10 +278,16 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     virtual void goToPos( const KateViRange &r );
     void executeCommand( const KateViCommand* cmd );
     OperationMode getOperationMode() const;
+    bool paste(bool leaveCursorAtStart);
+    bool pasteBefore(bool leaveCursorAtStart);
+    Cursor cursorPosAtEndOfPaste(const Cursor& pasteLocation, const QString& pastedText);
 
     void joinLines(unsigned int from, unsigned int to) const;
     void reformatLines(unsigned int from, unsigned int to) const;
 
+    KateViRange textObjectComma(bool inner);
+    void shrinkRangeAroundCursor(KateViRange& toShrink, const KateViRange& rangeToShrinkTo);
+
     QString m_keys;
     unsigned int m_countTemp;
     bool m_findWaitingForChar;
@@ -280,6 +301,7 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
     int m_motionOperatorIndex;
 
     QString m_lastTFcommand; // holds the last t/T/f/F command so that it can be repeated with ;/,
+    bool m_isRepeatedTFcommand;
 
     bool m_linewiseCommand;
     bool m_commandWithMotion;
@@ -300,11 +322,22 @@ class KATEPART_TESTS_EXPORT KateViNormalMode : public KateViModeBase
 
     // mappings
     bool m_mappingKeyPress;
+    // Will be the mapping used if we decide that no extra mapping characters will be
+    // typed, either because we have a mapping that cannot be extended to another
+    // mapping by adding additional characters, or we have a mapping and timed out waiting
+    // for it to be extended to a longer mapping.
+    // (Essentially, this allows us to have mappings that extend each other e.g. "'12" and
+    // "'123", and to choose between them.)
+    QString m_fullMappingMatch;
     // set after f/F/t/T/r so the following character isn't translated
     bool m_ignoreMapping;
     QString m_mappingKeys;
+    void executeMapping();
 
     KateViKeyParser *m_keyParser;
+
+    // Ctrl-c or ESC have been pressed, leading to a call to reset().
+    bool m_pendingResetIsDueToExit;
 };
 
 #endif
